%define ALD_Ver		2.0

#USE gcc-7.5.0

%define OrgName xz
%define mC_Version 1.2.4s

Name:         mC-%{OrgName}
License:      GPL LGPL
Summary:      XZ Utils provide data compression library and command line tools
Version:      5.2.3
Release:      %{mC_Version}.0

Source: %{OrgName}-%{version}.tar.xz

%define DestDir /Embedded/mC/%{mC_Version}
%define _prefix /usr/mC/%{mC_Version}
%define _bindir /usr/bin
%define _mandir /usr/share/man
# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}/mC/%{mC_Version}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%endif

# -----------------------------------------------------

%if %{have_auto_local}
%define __os_install_post %{nil}
%endif

%if %{_CROSS}
%define CrossPath /cross/%{_target_cpu}
%else
%define CrossPath %{nil}
%endif

#------------------ CROSS DIR --------------------

%define target %{_arch}-linux-musl
%define docdir %{_defaultdocdir}/%{OrgName}

# ------------------- description ------------------------------------
%description
XZ Utils provide a general-purpose data compression library and
command line tools. The native file format is the .xz format, but
also the legacy .lzma format is supported. The .xz format supports
multiple compression algorithms, which are called "filters" in
context of XZ Utils. The primary filter is currently LZMA2. With
typical files, XZ Utils create about 30 % smaller files than gzip.
# -------------------
%package bin
Summary:      %{OrgName} utilities static uClibc
Group:        System Environment/Base
%description bin
%{OrgName} utilities static uClibc

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

# ------------------- Build ------------------------------------------
%Build
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os -fno-tree-loop-optimize -fno-tree-dominator-opts -fno-strength-reduce"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"
export CFLAGS="$OPTFLAGS -std=gnu99"
export LDFLAGS="-Wl,--gc-sections"
export CC="%{target}-gcc"

./configure \
%if %{_CROSS}
	--host=%{_host} \
%endif
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--bindir=%{_bindir} \
	--mandir=%{_mandir} \
	--includedir=%{_includedir} \
	--disable-debug \
	--enable-assume-ram=32 \
	--disable-shared \
	--enable-static \
	--disable-libtool-lock \
	--disable-nls \
	--disable-rpath \
	--disable-scripts \
	--without-libintl-prefix \
	--enable-small \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la

cp -a AUTHORS COPYING README THANKS $RPM_BUILD_ROOT%{docdir}/

rm $RPM_BUILD_ROOT%{docdir}/COPYING.GPLv2
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING.GPLv2

rm -r $RPM_BUILD_ROOT%{docdir}/examples
rm -r $RPM_BUILD_ROOT%{docdir}/examples_old
rm -r $RPM_BUILD_ROOT%{docdir}/NEWS
rm -r $RPM_BUILD_ROOT%{docdir}/TODO
rm -r $RPM_BUILD_ROOT%{docdir}/faq.txt
rm -r $RPM_BUILD_ROOT%{docdir}/history.txt
rm -r $RPM_BUILD_ROOT%{docdir}/lzma-file-format.txt
rm -r $RPM_BUILD_ROOT%{docdir}/xz-file-format.txt

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-target_platform=%{target}-
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{docdir}
%{_includedir}
%{_libdir}/*.a
%{_libdir}/pkgconfig

%files bin
%{_bindir}
%{_mandir}
